.. image:: https://github.com/zopefoundation/Products.DCWorkflow/workflows/tests/badge.svg
        :target: https://github.com/zopefoundation/Products.DCWorkflow/actions?query=workflow%3Atests

.. image:: https://coveralls.io/repos/github/zopefoundation/Products.DCWorkflow/badge.svg
        :target: https://coveralls.io/github/zopefoundation/Products.DCWorkflow

.. image:: https://img.shields.io/pypi/v/Products.DCWorkflow.svg
        :target: https://pypi.org/project/Products.DCWorkflow/
        :alt: Current version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Products.DCWorkflow.svg
        :target: https://pypi.org/project/Products.DCWorkflow/
        :alt: Supported Python versions

Products.DCWorkflow
===================

This product provides fully customizable workflows for the CMF 
portal_workflow tool.
